summaryrefslogtreecommitdiff
path: root/src/theory/quantifiers/quant_conflict_find.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/theory/quantifiers/quant_conflict_find.cpp')
-rw-r--r--src/theory/quantifiers/quant_conflict_find.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/theory/quantifiers/quant_conflict_find.cpp b/src/theory/quantifiers/quant_conflict_find.cpp
index c71964565..5fa617670 100644
--- a/src/theory/quantifiers/quant_conflict_find.cpp
+++ b/src/theory/quantifiers/quant_conflict_find.cpp
@@ -29,10 +29,10 @@
#include "theory/quantifiers/term_util.h"
#include "theory/rewriter.h"
-using namespace CVC4::kind;
+using namespace CVC5::kind;
using namespace std;
-namespace CVC4 {
+namespace CVC5 {
namespace theory {
namespace quantifiers {
@@ -2349,6 +2349,6 @@ bool QuantConflictFind::isPropagatingInstance(Node n) const
return true;
}
-} /* namespace CVC4::theory::quantifiers */
-} /* namespace CVC4::theory */
-} /* namespace CVC4 */
+} // namespace quantifiers
+} // namespace theory
+} // namespace CVC5
generated by cgit on debian on lair
contact matthew@masot.net with questions or feedback